%
%% CONFIG_ST1_40_S23
%
% Calculates the various system parameters associated with the Quanser
% Shake Table 1-40-S23 system and the AMPAQ device.
%
% Output parameters:
%   Kt          Current-torque constant (N.m/A)
%   Km          Back-emf motor constant (V/(rad/s))
%   Pb          Ball screw pitch (m/rev)
%   Mp          Preload mass (i.e. mass even wo/ an additional load) (kg)
%   Ml_max      Maximum total load mass (kg)
%   Jeq         Equivalent Inertia of the loaded system (kg.m^2)
%   Tc          Total travel of stage (end to end) (m)
%   cal_tol     Calibration homing tolerance (m)
%   IMAX_UPM    Maximum output continuous current of amplifier (A)
%   VMAX_UPM    Maximum output voltage of amplifier (V)
%   P_MAX       Maximum position stage can deflect from home (m)
%   K_E_T       Encoder sensitivity gain (m/count)
%   K_CURR      Current sense sensitivity gain (A/V)
%
% Copyright (C) 2007 Quanser Consulting Inc.
% Quanser Consulting Inc.
%%
function [ Rm, Kt, Km, Pb, Mp, Ml_max, Jeq, Tc, cal_tol, IMAX_AMP, VMAX_AMP, P_MAX, K_E_T, K_CURR ] = config_STI_40( Ml )
%
% Calculate conversion factors
[ K_R2D, K_D2R, K_IN2M, K_M2IN, K_RDPS2RPM, K_RPM2RDPS, K_OZ2N, K_N2OZ, K_LBS2N, K_N2LBS, K_G2MS, K_MS2G ] = calc_conversion_constants ();
%
%% Motor Specs
% Motor armature resistance (ohm)
Rm = 1.45; 
% Motor Torque Constant (N.m/A)
Kt = 13.0 * K_IN2M * K_OZ2N;
% Speed Constant (V/(rad/s))
Km = 9.6 / 1000 / K_RPM2RDPS; 
% Peak current (A)
I_peak = 24.0;
% Continuous current (A)
I_cont = 3.0;
% Rotor Inertia (kg.m^2)
Jr = 0.06 * K_OZ2N / 9.81 * K_IN2M; %4.73e-6;
%
%% Linear Guide Specs
% Ball screw moment of inertia (kg.m^2)
Jb = 0.0471 / 100^2;
% Screw radius (m)
rb = 10 / 2 / 1000;
% Mass of block on linear guide (kg)
M_block = 1.92;
% Ball-screw Pitch (m/rev)
Pb = 10e-3;
% Specified stroke of linear guide (m)
T_stroke = 54e-3;
% Effective total table travel from left to right limit switch (m)
Tc = 0.04;
% Maximum stroke (m)
P_MAX = 0.021;
%
%% Table Specifications
% Stage mass (kg)
Ms = 0.70;
% Preload Mass - block and top stage (kg)
Mp = M_block + Ms;
% Maximum load mass to meet specification of table (2.5 g at 20 Hz) (kg)
Ml_max = 5;
% Check if added max exceeds maximum allotment
if (Ml > Ml_max)
    error('Mass of added load exceeds specified maximum load mass.');
end
% Total Mass that is being moved (kg)
Mt = Ml + Mp;
% Equivalent moment of inertia about motor shaft (kg.m^2)
Jm = Jr + Jb;
% Equivalent Inertia of the loaded system (kg.m^2)
Jeq = Jm + Mt * rb^2;
%
%% Calibration
% Calibration tolerance - set to positioning accuracy of guide (m)
cal_tol = 0.06e-3; % 60 um
%
%% Encoder
% Table Encoder Resolution (m/count)
K_E_T = Pb / ( 4 * 2048 );
%
%% VoltPAQ Specifications
% Current sensor calibration consant (A/V)
K_CURR =  1.0;
% AMPAQ Maximum Output Current (A)
IMAX_AMP = 4.0;
% AMPAQ Maximum Output Voltage (V)
VMAX_AMP = 24.0;