% SETUP_AMD1_PARAMETERS
%
% SETUP_AMD1_PARAMETERS accepts the user-defined configuration 
% of the Quanser's One-Floor Active Mass Damper (i.e. AMD-1) system. 
% SETUP_AMD1_PARAMETERS accordingly sets up and returns the 
% configuration-dependent model parameters of the Quanser AMD-1 plant.
%
% AMD-1 system nomenclature:
% Rm        Cart Motor Armature Resistance                       (Ohm)
% Kt        Cart Motor Torque Constant                           (N.m/A)
% Eff_m     Cart Motor Efficiency
% Km        Cart Motor Back-EMF Constant                         (V.s/rad)
% Kg        Cart Planetary Gearbox Gear Ratio
% Eff_g     Cart Planetary Gearbox Efficiency
% Jm        Cart Rotor Inertia                                  (kg.m^2)
% Mc        Total Mass of the Cart System (i.e. moving parts)   (kg)
% r_mp      Cart Motor Pinion Radius                            (m)
% Beq       Cart Equivalent Viscous Damping Coefficient 
%                       as seen at the Motor Pinion             (N.s/m)
% Mf        Floor Assembly Mass                                 (kg)
% Kf        Floor Linear Stiffness Constant                     (N/m)
% K_PC      if IP01: Cart Potentiometer Sensitivity             (m/V)
% K_EC      if IP02: Cart Encoder Resolution                    (m/count)
% K_ACC     Floor Accelerometer Sensitivity                     (m/s^2/V)
% VMAX_AMP  AMP Maximum Output Voltage                          (V)
% IMAX_AMP  AMP Maximum Output Current                          (A)
%
% Copyright (C) 2003 Quanser Consulting Inc.
% Quanser Consulting Inc.


%% returns the model parameters accordingly to the USER-DEFINED AMD1 system configuration
function [ Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, Mc, r_mp, Beq, Mf, Kf, K_EC, K_PC, K_ACC, VMAX_AMP, IMAX_AMP ] = setup_amd1_parameters( CART_TYPE, CART_LOAD_TYPE, AMP_TYPE )
% Calculate conversion factors
[ K_R2D, K_D2R, K_IN2M, K_M2IN, K_RDPS2RPM, K_RPM2RDPS, K_OZ2N, K_N2OZ, K_LBS2N, K_N2LBS, K_G2MS, K_MS2G ] = calc_conversion_constants ();
% Sets up the AMD cart model parameters accordingly to the user-defined configuration.
[ Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, Mc, r_mp, Beq, K_EC, K_PC, VMAX_AMP, IMAX_AMP ] = setup_amd_cart_parameters( CART_TYPE, CART_LOAD_TYPE, AMP_TYPE );
% Floor 1 Height (m)
Hf = 21 * K_IN2M; % = 0.5334;
% Rack Mass (kg)
Mr = 0.7;
% Flexible Structure Total Mass (with accelerometer) (kg)
Ms = 1.60;
% Structure Top Floor Mass (kg)
Mtf = 0.68;
% Top Floor/Roof (i.e. floor 1 + rack) Total Mass (kg)
Mf = Mr + Mtf; % = 1.38
% AMD-1's Top Floor Natural Frequency (Hz)
fn = 2.5;
% AMD-1's Top Floor Natural Angular Velocity (rad/s)
wn = 2 * pi * fn;
% AMD-1's Top Floor Linear Stiffness Constant (N/m)
Kf = ( Mf + Mc ) * wn^2; % = 500.9
% Floor Accelerometer Sensitivity (m/s^2/V)
% accelerometer calibration: 1.0 g/V
% positive floor acceleration is defined to the right when facing the AMD-1
K_ACC = 9.81;
% end of 'setup_amd1_parameters( )'
%
%
%% returns the model parameters accordingly to the USER-DEFINED AMD system configuration
function [ Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, Mc, r_mp, Beq, K_EC, K_PC, VMAX_AMP, IMAX_AMP ] = setup_amd_cart_parameters( CART_TYPE, CART_LOAD_TYPE, AMP_TYPE )
% Calculate conversion factors
[ K_R2D, K_D2R, K_IN2M, K_M2IN, K_RDPS2RPM, K_RPM2RDPS, K_OZ2N, K_N2OZ, K_LBS2N, K_N2LBS, K_G2MS, K_MS2G ] = calc_conversion_constants ();
% Motor Armature Resistance (Ohm)
Rm = 2.6;
% Motor Armature Inductance (H)
Lm = 180e-6;
% Motor Torque Constant (N.m/A)
Kt = 1.088 * K_OZ2N * K_IN2M; % = .00767
% Motor ElectroMechanical Efficiency [ = Tm * w / ( Vm * Im ) ]
Eff_m = 1;
% Motor Back-EMF Constant (V.s/rad)
Km = 0.804e-3 * K_RDPS2RPM; % = .00767
% Rotor Inertia (kg.m^2)
Jm = 5.523e-5 * K_OZ2N * K_IN2M; % = 3.9e-7
% Cart (IP01 or IP02) Mass, with 2 cable connectors (kg)
Mc = 0.39;
% Cart Weight Mass (kg)
Mw = 0.13;
% Planetary Gearbox (a.k.a. Internal) Gear Ratio
Kg = 3.71;
% Planetary Gearbox Efficiency
Eff_g = 1;
% Cart Motor Pinion number of teeth
N_mp = 24;
% Motor Pinion Radius (m)
r_mp = 0.5 / 2 * K_IN2M;  %  = 6.35e-3
% Cart Position Pinion number of teeth
N_pp = 56;
% Position Pinion Radius (m)
r_pp = 1.167 /2 * K_IN2M; %  = 14.8e-3
% Rack Pitch (m/teeth)
Pr = 1e-2 / 6.01; % = 0.0017
% Cart Travel (m)
Tc = 0.19;
% the cart position potentiometer goes from -5V to +5V in 10 turns
K_PC = 2 * pi * r_pp * 10 / 10; % = 0.0931
% Cart Encoder Resolution (m/count)
K_EC = Pr * N_pp / ( 4 * 1024 ); % = 22.7485 um/count
% Equivalent Viscous Damping Coefficient as seen at the Motor Pinion (N.s/m)
Beq = 3;
% Cart Total Mass (kg)
if strcmp ( CART_LOAD_TYPE, 'ONE_WEIGHT' )
    Mc = Mc + Mw;
elseif strcmp ( CART_LOAD_TYPE, 'TWO_WEIGHT' )
    Mc = Mc + 2 * Mw;
else 
    error( 'Error: Set the AMD cart load configuration.' )
end
% Set the AMP Maximum Output Voltage (V) and Output Current (A)
% rm: for low values of K_CABLE, VMAX_AMP is limited by VMAX_DAC
if  strcmp( AMP_TYPE, 'VoltPAQ' )
    VMAX_AMP = 24;
    IMAX_AMP = 4;
elseif  strcmp( AMP_TYPE, 'UPM_2405' )
    VMAX_AMP = 22;
    IMAX_AMP = 5;
elseif ( strcmp( AMP_TYPE, 'UPM_1503' ) | strcmp( AMP_TYPE, 'AMP_1503x2' ) ) 
    VMAX_AMP = 13;
    IMAX_AMP = 3;
elseif ( strcmp( AMP_TYPE, 'Q3' ) )
     IMAX_AMP = 4.0;
     VMAX_AMP = 2.6 * IMAX_AMP; % Multiply times resistance of SRV02
elseif ( strcmp( AMP_TYPE, 'AMPAQ' ) )
     IMAX_AMP = 5.0; 
     VMAX_AMP = 27.0;
else
    error( 'Error: Set the AMP type.' )
end
% end of 'setup_amd_cart_parameters( )'