%
%% D_STI_40_PD
%
% This script computes the open-loop model gain, Kf. The PD controller is
% then designed. Thus, using the model parameter Kf the proportional
% control gain, Kp, and the derivative control gain, Kd, are computed.
%
% Input parameters:
%   Kt      Current-torque constant (N.m/A) OR current-force constant (N/A)
%   Km      Back-emf constant (V/rad/s)
%   Mt      Total mass being moved (kg)
%   Pb      Ball-screw pitch (m/rev)
%   tp      Peak time (s)
%   PO      Percentage overshoot (%)
%
% Output parameters:
%   Kf      Open-loop model gain
%   K       PD vector control gain, K = [Kp, Kd] where Kp is the 
%           proportional control gain, and Kd is the  derivative control 
%           gain.
%
% Copyright (C) 2007 Quanser Consulting Inc.
% Quanser Consulting Inc.
%
function [Kf, K] = d_STI_40_pd(Kt, Km, Mt, Pb, Rm, tp, PO)
%
%% Model
% Model gain for X(s) = 1/Kf/s^2 * Im(s)
Kf = Mt * Pb / Kt;
%
%% Damping Ratio and Natural Frequency
% i) spec #1: Percent Overshoot (PO)
if ( PO > 0 )
    % using the *Hint provided in the lab, zeta_min is given by:
    zeta_min = abs( log( PO / 100 ) ) / sqrt( pi^2 + log( PO / 100)^2 );
    zeta = zeta_min;
else
    error( 'Error: Set Percentage Overshoot.' )
end
% ii) spec #2: Peak Time, tp (s)
wn = pi / ( tp * sqrt( 1 - zeta^2 ) );
%
%% PD Gains
% Proportional gain (V/m)
kp = wn^2 * Kf * Rm;
% Derivative gain (V.s/m)
kd = 2 * ( - Km * pi + zeta * wn * Kf * Pb * Rm ) / Pb;
% Vector gain
K = [kp,kd];
%