%% D_AMD1_OBS_CNTRL
%
% Designs the PV cart position control gains, the AMD state feedback
% controller, and loads parameters such as the low-pass filter
% specifications and sensors sensitivity gains (e.g. for the AMD
% accelerometer and cart encoder).
%
% Input parameters:
%   CART_TYPE           IP01/IP02 cart.
%   CART_LOAD_TYPE      Amount of load on cart (e.g. two-weight)
%   AMP_TYPE            Amplifier type (e.g. AMPAQ).
%   PO_c                Percentage overshoot for cart PV controller.
%   tp_c                Peak time for cart PV controller.
%   P                   Desired poles for AMD state-feedback control.
%   OP                  Desired poles for AMD observer.
%
% Output parameters:
%   wcf         Cart low-pass filter cutoff frequency           (rad/s)
%   zetaf       Cart low-pass filter damping ratio
%   wcf_a       Accelerometer low-pass filter cutoff frequency  (rad/s)
%   zetaf_a     Accelerometer low-pass filter damping ratio
%   K_ACC       Accelerometer Sensitivity gain                  (m/s^2V)
%   Kp_c        Cart position control proportional Gain         (A/m)
%   Kv_c        Cart position control velocity Gain             (A.s/m)
%   Kamd        Active-mass damper feedback gain                
%   Gamd        Active-mass damper observer gain
%   {A,B,C,D}   Linear state-space matrices of AMD-1
%   K_P_C       if IP01: Cart Potentiometer Sensitivity             (m/V)
%   K_E_C       if IP02: Cart Encoder Resolution                    (m/count)
%   K_ACC       Floor Accelerometer Sensitivity                     (m/s^2/V)
%   IMAX_IP01_2 Cart Maximum Current                                (A)
%
% Copyright (C) 2008 Quanser Consulting Inc.
% Quanser Consulting Inc.
%%
%
function [wcf, zetaf, wcf_a, zetaf_a, Kp_c, Kv_c, Kamd, Gamd, A, B, C, D, K_E_C, K_P_C, K_ACC, VMAX_AMD] = d_amd1_obs_cntrl(CART_TYPE, CART_LOAD_TYPE, AMP_TYPE, PO_c, tp_c, P, OP)
%
%% Low-Pass Filter Specifications
% Specifications of a IP02 second-order low-pass filter 
wcf = 2 * pi * 50;  % filter cutting frequency
zetaf = 0.9;        % filter damping ratio
% Specifications for accelerometer second-order low-pass filter 
wcf_a = 2 * pi * 35;  % filter cutting frequency
zetaf_a = 0.9;        % filter damping ratio
%
%% AMD and Sensor Parameters
% Set the model parameters for the AMD1 module, accordingly to the user-defined AMD-1 system configuration.
[ Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, Mc, r_mp, Beq, Mf, Ks, K_E_C, K_P_C, K_ACC, VMAX_AMD, IMAX_AMD ] = config_amd1( CART_TYPE, CART_LOAD_TYPE, AMP_TYPE );
%
%% Modeling and Control Design
% Proportional-Velocity (PV) controller as per the user-specifications above
[ Kp_c, Kv_c ] = d_ip01_2_position_pv( Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, Mc, r_mp, Beq, PO_c, tp_c, AMP_TYPE );    
% State-Space Representation of the Open-Loop System, X = [ xc; xf; xc_dot; xf_dot ]
% X = [ xc; xf; xc_dot; xf_dot ] and U = Vm
AMD1_ABCD_eqns;
% Put in terms of current, i.e. u = Fc to u = Im
% B = Eff_g * Kg * Eff_m * Kt * B / r_mp ;
% Put in terms of votlage, i.e. u = Fc to u = Vm
% B = Eff_g * Kg * Eff_m * Kt * B / r_mp;
% State-feedback controller design: calculate K
% state-feedback gain vector calculation: pole placement
Kamd = place( A, B, P );
% Full-Order Observer design: calculate G
% observer gain matrix calculation: pole placement
Gamd = place( A', C', OP )';
%