% D_IP01_2_PV_CONTROLLER
%
% IP01 or IP02 Position Control Lab: Design of a PV Controller
%
% D_IP01_2_PV_CONTROLLER designs a Proportional-plus-Velocity (PV) controller 
% for the IP01 or IP02 system, and returns the corresponding gains, Kp and Kv.
%
% PV controller nomenclature:
% Kp    Proportional Gain   (V/m)
% Kv    Velocity Gain       (V.s/m)
%
% Copyright (C) 2003 Quanser Consulting Inc.
% Quanser Consulting Inc.


function [ Kp, Kv ] = d_ip01_2_pv_controller( Rm, Jm, Kt, Eff_m, Km, Kg, Eff_g, M, r_mp, Beq, PO, tp, UPM_TYPE )
% I) Modelling: Laplace Transfer Function (see Maple worksheet)
% IP01 or IP02 Open Loop Transfer Function 
% of Motor Voltage Input (in Volts) to Cart Position (in meters).
if strcmp(UPM_TYPE,'Q3') || strcmp(UPM_TYPE,'AMPAQ')
    IP01_2_NUM(1) = Eff_g * Kg * Eff_m * Kt * r_mp;
    IP01_2_DEN(1) = Rm * ( M * r_mp^2 + Eff_g * Kg^2 * Jm);
    IP01_2_DEN(2) = Rm * Beq * r_mp^2;
    IP01_2_DEN(3) = 0;
else    
    IP01_2_NUM(1) = Eff_g * Kg * Eff_m * Kt * r_mp;
    IP01_2_DEN(1) = M * Rm * r_mp^2 + Rm * Eff_g * Kg^2 * Jm;
    IP01_2_DEN(2) = Beq * Rm * r_mp^2 + Eff_g * Kg^2 * Eff_m * Kt * Km;
    IP01_2_DEN(3) = 0;
end
% open-loop system
IP01_2_OL_SYS = tf( IP01_2_NUM, IP01_2_DEN );

% II) calculate the required controller gains, Kp and Kv
% meeting the desired specifications
% i) spec #1: maximum Percent Overshoot (PO)
% PO = 10 => zeta = 0.59
% and tp = 0.15 => wn = 26.00 rd/s
if ( PO > 0 )
    % using the *Hint provided in the lab, zeta_min is given by:
    zeta_min = abs( log( PO / 100 ) ) / sqrt( pi^2 + log( PO / 100)^2 );
    zeta = zeta_min;
else
    error( 'Error: Set Percentage Overshoot.' )
end
% ii) spec #2: tp - using the *Hint provided in the lab:
wn = pi / ( tp * sqrt( 1 - zeta^2 ) );
% alternative analytical form for wn:
%wn_test = sqrt( log( PO / 100 )^2 + pi^2 ) / tp;


% Using the control law: Vm = Kp * ( x_des - x ) - Kv * x_dot
% PV controller gain settings (see Maple worksheet):
Kp = ( wn^2 * IP01_2_DEN(1) - IP01_2_DEN(3) ) / IP01_2_NUM(1);
Kv = ( 2 * zeta * wn * IP01_2_DEN(1) - IP01_2_DEN(2) ) / IP01_2_NUM(1);

% alternatively, analytical form (see Maple worksheet):
%Kp = wn^2 * Rm * ( M * r_mp^2 + Eff_g * Kg^2 * Jm ) / ( r_mp * Eff_g * Kg * Eff_m * Kt );
%Kv = ( 2 * zeta * wn * Rm * M * r_mp^2 + 2 * zeta * wn * Rm * Eff_g * Kg^2 * Jm - Eff_g * Kg^2 * Eff_m * Kt * Km - Beq * Rm * r_mp^2 ) / ( r_mp * Eff_g * Kg * Eff_m * Kt );

% III) Closed-Loop System Response Simulation
% carrying out block diagram reduction:
% i) first of the inner velocity loop
KV_SYS = tf( [ Kv 0 ], [ 1 ] );
IP01_2_KV_OL_SYS = feedback( IP01_2_OL_SYS, KV_SYS );
% ii) then of the outer position loop
% to obtain the Overall Closed-Loop Transfer Function of the feedback-controlled system
Kp_IP01_2_KV_OL_SYS = Kp * IP01_2_KV_OL_SYS;
Kp_IP01_2_KV_CL_SYS = feedback( Kp_IP01_2_KV_OL_SYS, 1 );

%% optional: 
% flag to carry out some system analysis
%SYS_ANALYSIS = 'YES';
SYS_ANALYSIS = 'NO';
if strcmp( SYS_ANALYSIS, 'YES' )
    % normalization of the transfer function
    IP01_2_NUM = IP01_2_NUM / IP01_2_DEN(1);
    IP01_2_DEN = IP01_2_DEN / IP01_2_DEN(1);
    % print the OLTF
    printsys( IP01_2_NUM, IP01_2_DEN, 's' )
    % DC gain [m/s/V]
    Kdc = IP01_2_NUM(1) / IP01_2_DEN(2);
    % CL poles, damping, and natural frequency
    damp( Kp_IP01_2_KV_CL_SYS )
    % Simulated Unit Step Response of the Closed Loop System (without UPM saturation)
    figure ( 1 )
    step( Kp_IP01_2_KV_CL_SYS )
    set( 1, 'name', strcat( 'IP01 or IP02 with PV Controller: Kp= ', num2str( Kp ), ' V/m, Kv= ', num2str( Kv ), ' V.s/m') )
    grid on
end
% end of function 'd_ip01_2_pv_controller( )'
